![(https://img.shields.io/static/v1?label=version&message=1.1.0&color=yellow)](https://github.com/c4ssif3r/fileio_upload)
![(https://img.shields.io/static/v1?label=Owner&message=Mji~DarkPwn(C4SSIF3R)&color=black)](https://github.com/C4ssif3r)
![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)
![My Git!](https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white)](https://github.com/c4ssif3r)
![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)
![My Telegram](https://img.shields.io/badge/Telegram-100000?style=for-the-badge&logo=telegram&logoColor=white)](https://t.me/ZeroFoo)
![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)
![My Instagram](https://img.shields.io/badge/Instagram-100000?style=for-the-badge&logo=instagram&logoColor=white)](https://instagram.com/Mji_Devil)
![-----------------------------------------------------](https://raw.githubusercontent.com/andreasbm/readme/master/assets/lines/rainbow.png)
> #### What's the point?
  + To upload your files in File.io
  + Have you ever taken from a shell system?
    - Were you able to download a file?
    - `fileio_upload` is here !
    - In three whistles, install `fileio_upload` and upload your files to File.io:)
    - and ETC ...
> #### How's install this ?
```bash
pip install fileio_upload
```

> #### How's Create Downloader?

 ```python
from fileio_upload import Main

MyUploader = Main(file='myfile.jpg') # or file patch
MyUploader.upload()
```

